==> dmjone-0.1.9.9.tar.gz: dmjone-0.1.9.9/README.md <==
# dmjone

Official Python package for [dmj.one](https://dmj.one) - a platform dedicated to public welfare initiatives with a strong focus on educational projects. Our mission is to provide accessible, innovative, and valuable tools and resources for students, educators, and the general public to promote learning and educational excellence.

### Setting Up Your Environment
Before you start, set up a development environment. Ensure you have Python 3.0 or later installed.

## Installation
Install `dmjone` via pip. Ensure you have Python 3.7 or later installed.

```bash
pip install dmjone
```

## Quick Start
Here's a quick example to get you started with `dmjone`:

```python
# Method 1 - Import entire library 
import dmjone
# You can now use all functionalities available in the package library.

# Method 2 - Import your *own* specific code or functionalities
from dmjone import kaustuv as ks
# Now you can access specific functions of ks by calling ks.specific_function_name()

# Hello World ?
dmjone.hello()

# Get collaborating! Reserve your name at - dmjone._your-name_.function()
dmjone.aarushi.todolist()
dmjone.lakshika.calculator()
dmjone.jatin.demoName()
dmjone.kaustuv.calculate_absolute()
dmjone.subhojeet.packagebySubhojeet()
```

## Example Usage
Example 1
```python
import dmjone
dmjone.aarushi.todolist()
```
Example 2
```python
# Access the Student Management System, A Project by Students
import dmjone
dmjone.projectsms() # Ensure you have MySQL installed on your system if you are running it locally.
```
Example 3
```python
from dmjone import kaustuv as ks
ks.check_all_true()
```

## Notable User Contributions and Collaborations
#### Aarushi Sharma
- **TodoList**: A simple To-Do List creator.
#### Kaustuv Sharma
- **Calculate Absolute Value**: Calculate absolute value of a given number
#### Lakshika Tanwar
- **Typecasting**: Demonstrate Typecasting in python
- **Calculator**: Calculator to do arithmetic operations on numbers

## Highlighted Features and Collaborations
- **Student Management System**: A simple yet powerful system for managing student records, designed for educational institutions.
- **Lab Projects**: Access to various educational projects and lab work to facilitate learning and teaching.
- **Educational Tools**: A collection of tools aimed at enhancing the learning experience.

## Authors
- Subject Experts: **Dr. Anurag Rana** [GitHub](https://github.com/AI-ARana) | **Dr. Pankaj Vaidya**
- **Divya Mohan** - _init_ - [GitHub](https://github.com/divyamohan1993) |  **Lakshika Tanwar** - *Top Contributor* - [GitHub](https://github.com/LakshikaTanwar) | **Aarushi Sharma** - *Contributor* - [GitHub](https://github.com/letscodeitup) | **Kaustuv Sharma** - *Contributor* - [GitHub](https://github.com/kaustuvsharma)
- **Anshuman Mohanty** - [GitHub](https://github.com/anshumanmohanty00) | **Ashutosh Rana** | **Jatin Sharma** | **Rijul Chaudhary** - [GitHub](https://github.com/Rijul777) | **Subhojeet Ghosh** [GitHub](https://github.com/subhojeetghosh123) | **Vedansh Sharma** - [GitHub](https://github.com/Elysian-Reverie) | **Yuvraj Kumar** [GitHub](https://github.com/YuvRaj-Kumar-95)

See also the list of [contributors](https://github.com/dmjone/dmjone_pypi/contributors) who participated in this project.

## How To Contribute

We thank you for your interest in contributing to `dmjone`! 🎉 Your efforts make a big difference. Whether you're fixing a bug, adding a feature, or improving documentation, we appreciate your help. Here’s how to contribute in a friendly and easy way:

#### Found a solution to a problem? Let's get you started!

1. **Find something to work on**: Look through the [GitHub issues](https://github.com/dmjone/dmjone_pypi/issues) for something that interests you or open a new issue to suggest improvements or report bugs.

#### Making Changes

##### Using GitHub Web Interface
For small changes, like fixing typos or small code snippets, using the GitHub web interface is the easiest way:

1. Navigate to the file you want to edit on the [dmjone GitHub Repo](https://github.com/dmjone/dmjone_pypi).
2. Click the pencil icon (Edit this file) to start making changes.
3. After making changes, describe what you did and why in the **Commit changes** box.
4. Choose the option to **Create a new branch for this commit and start a pull request**. Name it appropriately, like `fix/typo-in-readme`.
5. Click **Propose changes** and then **Create pull request** on the next page.

##### Using Command Line
For larger changes or new features, you might prefer working locally:

1. **Fork the Repository**: Click the "Fork" button on the top right of the [dmjone GitHub Repo](https://github.com/dmjone/dmjone_pypi) page to create your copy.
2. **Clone Your Fork**: `git clone https://github.com/your-username/dmjone_pypi.git` to clone the project to your computer.
3. **Create a Branch**: Switch to your clone and use `git checkout -b feature/YourFeatureName` or `fix/YourBugFix` to create a new branch.
4. **Make Your Changes**: Add your changes using your favorite editor or IDE.
5. **Commit Your Changes**: Use `git commit -m 'A brief description of your changes'` to save your work.
6. **Push to GitHub**: Use `git push origin feature/YourFeatureName` to upload your changes to your GitHub fork.
7. **Open a Pull Request**: Go to your fork on GitHub and press the "New pull request" button. Describe your changes and submit!

### Before You Submit

- **Review Your Changes**: Double-check your changes and make sure everything works as expected. Try to keep your changes simple and focused on solving a single problem.
- **Follow the Style Guide**: Make sure your contributions follow the existing code style to keep the project organized.
- **Update Tests**: If you're adding a new feature, consider adding tests to support it.

### Submitting Your Contribution

Once you’re ready to submit, open a pull request with your changes. Provide a clear description of the problem and solution, including any relevant issue numbers.

### After You Submit

- **Patience is Key**: Maintainers will review your contribution and may suggest changes. This is a normal part of the process; feedback helps improve the project.
- **Stay Engaged**: Check back in case the maintainers have questions or feedback. Your pull request may spark a conversation.

### And That's It!

You've contributed to `dmjone`! We're grateful for your help in making this project better. Remember, contributing is not just about code; every bit of documentation, bug reports, or even suggestions are valuable to us.

Thank you for being part of our open-source community! Let the world be educated!🌟

## Acknowledgements
- Shoolini University
- All educators and students at Shoolini University

## Contact
For any queries, please reach out to us via [the message button on dmj.one](https://dmj.one/).

## Documentation
<!-- For comprehensive documentation, visit [dmj.one/docs](https://dmj.one/docs). Here, you'll find detailed information on how to make the most of the tools and resources offered by `dmjone`. -->
For comprehensive documentation, visit [dmj.one](https://dmj.one). Here, you'll find detailed information on how to make the most of the tools and resources offered by `dmjone`.

## License
Distributed under the GPL-3.0 License. See `LICENSE` for more information.

## Project Links

- **Project Homepage**: [dmj.one](https://dmj.one)
- **PyPI Repository**: [dmjone on PyPI](https://pypi.org/project/dmjone/)
- **Source Code**: [GitHub Repository](https://github.com/dmjone/dmjone_pypi)

==> dmjone-0.2.tar.gz: dmjone-0.2/README.md <==
# dmjone

Official Python package for [dmj.one](https://dmj.one) - a platform dedicated to public welfare initiatives with a strong focus on educational projects. Our mission is to provide accessible, innovative, and valuable tools and resources for students, educators, and the general public to promote learning and educational excellence.

### Setting Up Your Environment
Before you start, set up a development environment. Ensure you have Python 3.0 or later installed.

## Installation
Install `dmjone` via pip. Ensure you have Python 3.7 or later installed.

```bash
pip install dmjone
```

## Quick Start
Here's a quick example to get you started with `dmjone`:

```python
# Method 1 - Import entire library 
import dmjone
# You can now use all functionalities available in the package library.

# Method 2 - Import your *own* specific code or functionalities
from dmjone import kaustuv as ks
# Now you can access specific functions of ks by calling ks.specific_function_name()

# Hello World ?
dmjone.hello()

# Get collaborating! Reserve your name at - dmjone._your-name_.function()
dmjone.aarushi.todolist()
dmjone.lakshika.calculator()
dmjone.jatin.demoName()
dmjone.kaustuv.calculate_absolute()
dmjone.subhojeet.packagebySubhojeet()
```

## Example Usage
Example 1
```python
import dmjone
dmjone.aarushi.todolist()
```
Example 2
```python
# Access the Student Management System, A Project by Students
import dmjone
dmjone.projectsms() # Ensure you have MySQL installed on your system if you are running it locally.
```
Example 3
```python
from dmjone import kaustuv as ks
ks.check_all_true()
```

## Notable User Contributions and Collaborations
#### Aarushi Sharma
- **TodoList**: A simple To-Do List creator.
#### Kaustuv Sharma
- **Calculate Absolute Value**: Calculate absolute value of a given number
#### Lakshika Tanwar
- **Typecasting**: Demonstrate Typecasting in python
- **Calculator**: Calculator to do arithmetic operations on numbers

## Highlighted Features and Collaborations
- **Student Management System**: A simple yet powerful system for managing student records, designed for educational institutions.
- **Lab Projects**: Access to various educational projects and lab work to facilitate learning and teaching.
- **Educational Tools**: A collection of tools aimed at enhancing the learning experience.

## Authors
- Subject Matter Experts: **Dr. Anurag Rana** [GitHub](https://github.com/AI-ARana) | **Dr. Pankaj Vaidya** | **Dr. Gaurav Gupta** [GitHub](https://github.com/solangaurav) 
- **Divya Mohan** - _init_ - [GitHub](https://github.com/divyamohan1993) |  **Lakshika Tanwar** - *Top Contributor* - [GitHub](https://github.com/LakshikaTanwar) | **Aarushi Sharma** - *Contributor* - [GitHub](https://github.com/letscodeitup) | **Kaustuv Sharma** - *Contributor* - [GitHub](https://github.com/kaustuvsharma) | **Aarchit Joshi**
- **Anshuman Mohanty** - [GitHub](https://github.com/anshumanmohanty00) | **Ashutosh Rana** | **Jatin Sharma** | **Rijul Chaudhary** - [GitHub](https://github.com/Rijul777) | **Subhojeet Ghosh** [GitHub](https://github.com/subhojeetghosh123) | **Vedansh Sharma** - [GitHub](https://github.com/Elysian-Reverie) | **Yuvraj Kumar** [GitHub](https://github.com/YuvRaj-Kumar-95)

See also the list of [contributors](https://github.com/dmjone/dmjone_pypi/contributors) who participated in this project.

## How To Contribute

We thank you for your interest in contributing to `dmjone`! 🎉 Your efforts make a big difference. Whether you're fixing a bug, adding a feature, or improving documentation, we appreciate your help. Here’s how to contribute in a friendly and easy way:

#### Found a solution to a problem? Let's get you started!

1. **Find something to work on**: Look through the [GitHub issues](https://github.com/dmjone/dmjone_pypi/issues) for something that interests you or open a new issue to suggest improvements or report bugs.

#### Making Changes

##### Using GitHub Web Interface
For small changes, like fixing typos or small code snippets, using the GitHub web interface is the easiest way:

1. Navigate to the file you want to edit on the [dmjone GitHub Repo](https://github.com/dmjone/dmjone_pypi).
2. Click the pencil icon (Edit this file) to start making changes.
3. After making changes, describe what you did and why in the **Commit changes** box.
4. Choose the option to **Create a new branch for this commit and start a pull request**. Name it appropriately, like `fix/typo-in-readme`.
5. Click **Propose changes** and then **Create pull request** on the next page.

##### Using Command Line
For larger changes or new features, you might prefer working locally:

1. **Fork the Repository**: Click the "Fork" button on the top right of the [dmjone GitHub Repo](https://github.com/dmjone/dmjone_pypi) page to create your copy.
2. **Clone Your Fork**: `git clone https://github.com/your-username/dmjone_pypi.git` to clone the project to your computer.
3. **Create a Branch**: Switch to your clone and use `git checkout -b feature/YourFeatureName` or `fix/YourBugFix` to create a new branch.
4. **Make Your Changes**: Add your changes using your favorite editor or IDE.
5. **Commit Your Changes**: Use `git commit -m 'A brief description of your changes'` to save your work.
6. **Push to GitHub**: Use `git push origin feature/YourFeatureName` to upload your changes to your GitHub fork.
7. **Open a Pull Request**: Go to your fork on GitHub and press the "New pull request" button. Describe your changes and submit!

### Before You Submit

- **Review Your Changes**: Double-check your changes and make sure everything works as expected. Try to keep your changes simple and focused on solving a single problem.
- **Follow the Style Guide**: Make sure your contributions follow the existing code style to keep the project organized.
- **Update Tests**: If you're adding a new feature, consider adding tests to support it.

### Submitting Your Contribution

Once you’re ready to submit, open a pull request with your changes. Provide a clear description of the problem and solution, including any relevant issue numbers.

### After You Submit

- **Patience is Key**: Maintainers will review your contribution and may suggest changes. This is a normal part of the process; feedback helps improve the project.
- **Stay Engaged**: Check back in case the maintainers have questions or feedback. Your pull request may spark a conversation.

### And That's It!

You've contributed to `dmjone`! We're grateful for your help in making this project better. Remember, contributing is not just about code; every bit of documentation, bug reports, or even suggestions are valuable to us.

Thank you for being part of our open-source community! Let the world be educated!🌟

## Acknowledgements
- Shoolini University
- All educators and students at Shoolini University

## Contact
For any queries, please reach out to us via [the message button on dmj.one](https://dmj.one/).

## Documentation
<!-- For comprehensive documentation, visit [dmj.one/docs](https://dmj.one/docs). Here, you'll find detailed information on how to make the most of the tools and resources offered by `dmjone`. -->
For comprehensive documentation, visit [dmj.one](https://dmj.one). Here, you'll find detailed information on how to make the most of the tools and resources offered by `dmjone`.

## License
Distributed under the GPL-3.0 License. See `LICENSE` for more information.

## Project Links

- **Project Homepage**: [dmj.one](https://dmj.one)
- **PyPI Repository**: [dmjone on PyPI](https://pypi.org/project/dmjone/)
- **Source Code**: [GitHub Repository](https://github.com/dmjone/dmjone_pypi)
